@@ -2,6 +2,8 @@ from typing import NamedTuple, Union
 
 import pydantic
 
+from compass.core.schemas import hierarchy as schema
+
 
 class UnitRecord(NamedTuple):
     """Storage format for Units."""
@@ -17,5 +19,5 @@ class UnitRecordModel(pydantic.BaseModel):
 
     name: str
     parent: int
-    children: Union[dict[int, str], None]
-    sections: Union[dict[int, str], None]
+    children: list[schema.HierarchyUnit]
+    sections: list[schema.HierarchyUnit]
